@@ -22,50 +22,36 @@
 
 ## Methods for classes 'RFempVario' and 'RFfit'  #######################
 
-
-summary.RFempVariog <- function(object, ...) {
-  variogram <- object@emp.vario
+summary_RFempVariog <- function(OP, object, ...) {
+  variogram <- do.call(OP, list(object, "emp.vario"))
   if (is.array(variogram)) {
     dims <- dim(variogram)
     dims <- dims[dims > 1]
     dim(variogram) <- dims
   }
-  l <- list(centers=object@centers,
+  l <- list(centers=do.call(OP, list(object, "centers")),
             variogram=variogram)
-  if (length(object@sd) > 0) {
-    l$sd <- object@sd
+  obj <- do.call(OP, list(object, "sd"))
+  if (length(obj) > 0) {
+    l$sd <- obj
     if (is.array(variogram)) dim(l$sd) <- dims
   }
-  
-  if (length(object@phi.centers) > 1) l$phi <- object@phi.centers
-  if (length(object@theta.centers) > 1) l$theta <- object@theta.centers
-  if (length(object@T)>0) l$T <- object@T
-  if (object@vdim > 1) l$vdim <- object@vdim  
+
+  obj <- do.call(OP, list(object, "phi.centers"))
+  if (length(obj) > 1) l$phi <- obj
+  obj <- do.call(OP, list(object, "theta.centers"))
+  if (length(obj) > 1) l$theta <- obj
+  obj <- do.call(OP, list(object, "T"))
+  if (length(obj)>0) l$T <- obj
+  obj <- do.call(OP, list(object, "vdim"))
+  if (obj > 1) l$vdim <- obj
   class(l) <- "summary.RFempVariog"
   l
 }
 
-summary.RF_empVariog <- function(object, ...) {
-  variogram <- object$emp.vario
-  if (is.array(variogram)) {
-    dims <- dim(variogram)
-    dims <- dims[dims > 1]
-    dim(variogram) <- dims
-  }
-  l <- list(centers=object$centers,
-            variogram=variogram)
-  if (length(object$sd) > 0) {
-    l$sd <- object$sd
-    if (is.array(variogram)) dim(l$sd) <- dims
-  }
-  
-  if (length(object$phi.centers) > 1) l$phi <- object$phi.centers
-  if (length(object$theta.centers) > 1) l$theta <- object$theta.centers
-  if (length(object$T)>0) l$T <- object$T
-  if (object$vdim > 1) l$vdim <- object$vdim
-  class(l) <- "summary.RFempVariog"
-  l
-}
+summary.RFempVariog <- function(object, ...) summary_RFempVariog("@",object,...)
+summary.RF_empVariog <- function(object,...) summary_RFempVariog("$",object,...)
+
 
 
 print.summary.RFempVariog <- function(x, ...) {
@@ -117,42 +103,14 @@ list2RFempVariog <- function(li) {
 
 ## plot method
 
-setMethod(f="plot", signature(x="RFempVariog", y="missing"),
-	  definition=function(
-            x, model = NULL, nmax.phi=NA, nmax.theta=NA, nmax.T=NA,
-            plot.nbin=TRUE, plot.sd=FALSE, variogram=TRUE,
-            boundaries = TRUE,...){ 
-          plotRFempVariog(x, model = model,
-                          nmax.phi=nmax.phi, nmax.theta=nmax.theta,
-                          nmax.T=nmax.T, plot.nbin=plot.nbin, plot.sd=plot.sd,
-                          variogram=variogram, boundaries = boundaries,
-                          ...)
-                   })
-
-
-setMethod(f="persp", signature(x="RFempVariog"),
-	  definition=function(
-            x, model = NULL, nmax.phi=NA, nmax.theta=NA, nmax.T=NA,
-            plot.nbin=TRUE, plot.sd=FALSE, variogram=TRUE,
-            boundaries = TRUE,...){ 
-            plotRFempVariog(x, model = model,
-                          nmax.phi=nmax.phi, nmax.theta=nmax.theta,
-                          nmax.T=nmax.T, plot.nbin=plot.nbin, plot.sd=plot.sd,
-                          variogram=variogram, boundaries = boundaries,
-                          ..., plotmethod=graphics::persp)
-                   })
-
-
-
 
 plotRFempVariogUnbinned <- function(x, coordunits, varunits, varnames,
-                                    ..., plotmethod="image") {
+                                    legend, ..., plotmethod="plot") {
+  stop("currently not used ") # !!
+  graphics <- RFoptions()$graphics
   dots = mergeWithGlobal(list(...))
   dotnames <- names(dots)
-  coords <- GridTopology2gridVectors(cbind(x@centers$x, x@centers$T))
-
-  #Print(coords, "plotRFempVariogUnbinned")
-  
+  coords <- GridTopology2gridVectors(cbind(x@centers$x, x@centers$T))  
   if (length(coords)>1) {    
     coords[[1]] <- sort(unique((coords[[1]] - min(coords[[1]])) *
                                rep(c(-1, 1), each=length(coords[[1]]))))
@@ -202,78 +160,101 @@ plotRFempVariogUnbinned <- function(x, coordunits, varunits, varnames,
   range.ev <- range(ev.plot)#x@emp.vario)
   col <- if ("col" %in% dotnames) dots$col else
   default.image.par(NULL, NULL)$default.col
-  
-  split.screen( rbind(c(0,.85,0,1), c(.85,1,0,1)))
-  screen(2)
-  par(mar=c(4,0,3,3))
-  z.legend <- seq(range.ev[1], range.ev[2], length=length(col))
-    image(y=z.legend, x=c(0,1), z=rbind(z.legend, z.legend), axes=F, col=col,
-          xlab="")
-  axis(4)
-  box()
-  screen(1)
-  par(mar=c(4,4,3,1))
-  dots$type <- NULL
 
+  if (graphics$split.screen && legend) {
+    scr <- split.screen( rbind(c(0,.85,0,1), c(.85,1,0,1)))
+    screen(scr[1])
+    par(mar=c(4,4,3,1))
+  } else {
+    scr <- NULL
+    par(mar=c(4,4,3,1))
+  }
+
+  dots$type <- NULL
   do.call(plotmethod,
           args=c(dots, list(x=coords[[1]], y=coords[[2]], z=ev.plot)))
                                         #      xlab=lab.names[1],
                                         #      ylab=lab.names[2],
                                         #      main="Variogram image plot")
-  close.screen(all.screens=TRUE)
-  return(invisible())
+  if (legend) {
+    stop("das ist doch quark?!")
+   
+    
+    if (graphics$split.screen) {
+      screen(scr[2])
+      par(mar=c(4,0,3,3))
+      z.legend <- seq(range.ev[1], range.ev[2], length=length(col))
+      image(y=z.legend, x=c(0,1), z=rbind(z.legend, z.legend), axes=F, col=col,
+            xlab="")
+      axis(4)
+      box()
+    } else {
+      my.legend(min(coords[[1]]), max(coords[[2]]), range(ev.plot),
+                col=col, bg="white")
+    }
+  }
+
+  if (graphics$close_screen) {
+    close.screen(scr)
+    scr <- NULL
+  }
+  return(invisible(scr))
 }
 
-plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
-                            plot.nbin, plot.sd, method = NULL,
-                            variogram=variogram,
-                            coordunits=c(""),
-                            varunits=c(""),
-                            boundaries = TRUE,
-                            ...) {
+
+RFplotEmpVariogram <- function(x, model = NULL, nmax.phi = NA, nmax.theta = NA,
+                               nmax.T = NA,
+                               plot.nbin = TRUE, plot.sd=FALSE, method = "ml",
+                               variogram=TRUE,
+                               boundaries = TRUE,
+                               ...) {
   if (!variogram)
     stop("plot of estimated covariance functions not programmed yet.")
-  
 
+  graphics <- RFoptions()$graphics
   newx <- list()
   methodnames <- double()
-  if (is(x, "RFfit")) {    
-    if(length(x@ev)==0) stop("The fit does not contain an empirical variogram.")
-    newx$autostart <- x@autostart
-    newx$self <- x@self
-    newx$plain <- x@plain
-    newx$sqrt.nr <- x@sqrt.nr
-    newx$sd.inv <- x@sd.inv
-    newx$internal1 <- x@internal1
-    newx$internal2 <- x@internal2
-    newx$internal3 <- x@internal3
-    newx$ml <- x@ml
+  if (is(x, "RFfit") || is(x, "RF_fit")) {
+    OP <- c("$", "@")[1 + is(x, "RFfit")]
+    if(length(do.call(OP, list(x, "ev")))==0) stop("The fit does not contain an empirical variogram.")
+    newx$autostart <- do.call(OP, list(x, "autostart"))
+    newx$self <- do.call(OP, list(x, "self"))
+    newx$plain <- do.call(OP, list(x, "plain"))
+    newx$sqrt.nr <- do.call(OP, list(x, "sqrt.nr"))
+    newx$sd.inv <- do.call(OP, list(x, "sd.inv"))
+    newx$internal1 <- do.call(OP, list(x, "internal1"))
+    newx$internal2 <- do.call(OP, list(x, "internal2"))
+    newx$internal3 <- do.call(OP, list(x, "internal3"))
+    newx$ml <- do.call(OP, list(x, "ml"))
 
-    
-    x <- x@ev
+    x <- do.call(OP, list(x, "ev"))
     if( is.null(method) )
       method <- if (length(newx$ml@name) > 0) "ml" else "plain"
 
-    methodidx <- method %in% names(newx[unlist(lapply(newx, FUN = function(x) is(x, ZF_MODELEXT)))])
+    methodidx<-names(newx[unlist(lapply(newx, function(x) is(x, ZF_MODELEXT)))])
+    methodidx <- method %in% methodidx
     methodnames <- method[methodidx]
     nomethodnames <- method[!methodidx]
 
     if( !all(methodidx) )
       warning( paste("The following method does not exist: ", nomethodnames) )
-  } else if (!is(x, "RFempVariog"))
-    stop("method only for objects of class 'RFempVariog' or 'RFfit'")
+  } else {
+    if (!is(x, "RFempVariog") && !is(x, "RF_empVariog"))
+      stop("method only for objects of class 'RFempVariog' or 'RFfit'")
+    OP <- c("$", "@")[1 + is(x, "RFempVariog")]
+  }
+ 
+  ev <- do.call(OP, list(x, "emp.vario"))
+  sd <- do.call(OP, list(x, "sd"))
+  centers <- do.call(OP, list(x, "centers"))
+  phi.centers <- do.call(OP, list(x, "phi.centers"))
+  theta.centers <- do.call(OP, list(x, "theta.centers"))
+  Time <- do.call(OP, list(x, "T"))
+  n.bin <- do.call(OP, list(x, "n.bin"))
+  coordunits <- do.call(OP, list(x, "coordunits"))
 
-
-  varnames <-
-    if (is.matrix(x@emp.vario)) dimnames(x@emp.vario)[[2]][1]
-    else names(x@emp.vario)[1]
+  varnames <- if (is.matrix(ev)) dimnames(ev)[[2]][1] else names(ev)[1]
  
-  ## case without binning
-  if (is.list(x@centers))
-    return(plotRFempVariogUnbinned(x=x,                         
-                                   coordunits=coordunits,
-                                   varunits=varunits,
-                                   varnames=varnames, ...))       
   dots = list(...)
   dotnames <- names(dots)
    if (!("type" %in% dotnames)) dots$type <- "b" 
@@ -282,7 +263,7 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
   dots$cex <- NULL
   if (!("pch" %in% dotnames)) dots$pch <- 19
              
-  if(!("xlim" %in% dotnames)) dots$xlim <- range(x@centers)
+  if(!("xlim" %in% dotnames)) dots$xlim <- range(centers)
   ylim.not.in.dotnames <- !("ylim" %in% dotnames)
   xlab <- if ("xlab" %in% dotnames) dots$xlab else "distance"
   dots$xlab <- NULL
@@ -294,7 +275,7 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
   if (!is.null(main0)) oma.top <- 2 else oma.top <- 0
   
 
-  has.sd <- !is.null(x@sd)
+  has.sd <- !is.null(sd)
   
  if(!is.null(model)) {
    if (!is.list(model)) model <- list(model)
@@ -308,13 +289,13 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
     newx <- c(newx, model)
  }
   n.methods <- length(methodnames)
-  
-    
-  n.phi <- min(nmax.phi, l.phi <- max(1,length(x@phi.centers)), na.rm=TRUE)
-  n.theta <- min(nmax.theta, l.theta <- max(1,length(x@theta.centers)),
+
+
+  n.phi <- min(nmax.phi, l.phi <- max(1,length(phi.centers)), na.rm=TRUE)
+  n.theta <- min(nmax.theta, l.theta <- max(1,length(theta.centers)),
                  na.rm=TRUE)
-  n.T <- min(nmax.T, l.T <- max(1,length(x@T)), na.rm=TRUE)
-  vdim <- dim(x@emp.vario)
+  n.T <- min(nmax.T, l.T <- max(1,length(Time)), na.rm=TRUE)
+  vdim <- dim(ev)
   vdim <- vdim[length(vdim)]
 
   if (n.phi > 6 || n.theta > 3 || n.T > 3)
@@ -329,11 +310,11 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
     theta.angles <- theta.angles * 0.96
   } 
   
-  TandV <- n.T > 1 && vdim > 1
+  TandV <- (n.T > 1 && vdim > 1) && graphics$split_screen
   if (vdim>1 && length(varnames)==0)
     varnames <- paste("v", 1:vdim, sep="")
 
-  range.nbin <- range(c(0, x@n.bin), na.rm=TRUE)
+  range.nbin <- range(c(0, n.bin), na.rm=TRUE)
   ylim.nbin <- range.nbin * c(1,1.2)
   
   col.v <- col <- 
@@ -372,13 +353,18 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
   }
 
   oma.left <- 6
-  Screens <- if (!TandV) c(n.T * vdim * vdim, n.theta) else  c(n.T, n.theta)
-  n.all <- prod(Screens)
-  if (any(par()$mfcol != c(1,1))) par(mfcol=c(1,1))
+  Screens <- if (TandV) c(n.T, n.theta) else c(n.T * vdim * vdim, n.theta)
+  ArrangeDevice(graphics, Screens)
 
+  all.scr <- scr <- (if (!graphics$split_screen) NULL else
+              split.screen(if (TandV) c(vdim, vdim) else Screens))
+    
   for (v1 in 1:vdim) {
     for (v2 in 1:vdim) {
-      if (TandV || (v1==1 && v2==1)) scr <- split.screen(Screens)
+      if (TandV) {
+        scr <- split.screen(Screens, all.scr[v1 + (v2 - 1) * vdim])
+        all.scr <- c(all.scr, scr)
+      }
       if (vdim == 1) {
         main <-
           if (!is.null(main0) && length(varnames)>0)
@@ -389,7 +375,7 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
           else paste(main0, "for", varnames[v1], "vs.",  varnames[v2])
       }      
       if (ylim.not.in.dotnames)
-        dots$ylim <- range(x@emp.vario[,,,, v1, v2], na.rm=TRUE)
+        dots$ylim <- range(ev[,,,, v1, v2], na.rm=TRUE)
       for (iT in 1:n.T) {
         for (ith in 1:n.theta) {
           ## plot n.bin
@@ -397,13 +383,15 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
             screen(scr[1])
             par(oma=c(4,oma.left,oma.top,0))
             scr2 <- split.screen(rbind(c(0,1,.2,1), c(0,1,0,.2)), screen=scr[1])
+            all.scr <- c(all.scr, scr2)
             screen(scr2[2])
             par(mar=c(0,.5,0,.5))
             for (iph in 1:n.phi) {
               if (n.phi > 1) col <- col.v[iph]
               if (iph==1) {
-                lab <- xylabs("bin centers", NULL, units=x@coordunits)
-                plot(x@centers, x@n.bin[ ,iph, ith, iT, v1, v2],
+                lab <- xylabs("bin centers", NULL, units=coordunits)
+                plot(centers,
+                     n.bin[ ,iph, ith, iT, v1, v2],
                      xlim=dots$xlim, ylim=ylim.nbin,
                      type=if (n.phi>1) "p" else "h",
                      col =if (n.phi>1) col else "darkgray", lwd=4,
@@ -420,7 +408,7 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
                 if (ith==1) title(ylab="n.bin", line=5, outer=TRUE, adj=0)
                 
               } else {
-                points(x@centers, x@n.bin[ ,iph, ith, iT, v1, v2],
+                points(centers, n.bin[ ,iph, ith, iT, v1, v2],
                        type="p", col=col, pch=16)
               }
             }
@@ -439,10 +427,12 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
           for (iph in 1:n.phi) {
             if (n.phi>1) col <- col.v[iph]
             if (iph==1) {
-              do.call(graphics::plot, args=c(dots, list(
-                              x=x@centers, y=x@emp.vario[ ,iph, ith, iT, v1,v2],
+              do.call(graphics::plot,
+                      c(dots, list(
+                          x=centers,
+                          y=ev[,iph,ith,iT,v1,v2],
                                         #ylim=ylim.ev, type=type, pch=19,
-                              col=col, axes=FALSE, ylab=""))
+                          col=col, axes=FALSE, ylab=""))
                       )
               box()
               axis(2, las=1, labels=(ith==1), outer=(ith==1))
@@ -451,9 +441,10 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
                 L <- character(3)
                 if (!TandV && vdim > 1) L[1] <- paste(varnames[c(v1,v2)],
                                                       collapse=":")
-                if (l.T>1) L[2] <- paste("T=",signif(x@T[iT],3)," ",sep="")
-                if (l.theta>1) L[3] <- paste(sep="", "theta=",
-                                             signif(x@theta.centers[ith],3))
+                if (l.T>1) L[2] <-
+                  paste("T=",signif(Time[iT], 3), " ", sep="")
+                if (l.theta>1) L[3] <-
+                  paste(sep="", "theta=", signif(theta.centers[ith],3))
                 legend("topleft", legend=paste(L[L!=""], collapse=","))
               }
               if (ith == 1) title(ylab=ylab.ev, line=5, outer=TRUE)
@@ -462,9 +453,10 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
                        legend="arrows represent +-1 sd intervals")
               
             } else {  ## iph > 1
-              do.call(graphics::points, args=c(dots, list(
-                                x=x@centers,
-                                y=x@emp.vario[ ,iph, ith, iT, v1, v2], col=col))
+              do.call(graphics::points,
+                      c(dots, list(x=centers,
+                                   y=ev[,iph,ith,iT,v1,v2],
+                                   col=col))
                       )   #type=type,  pch=19)
             } ## if iph 
             
@@ -477,19 +469,19 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
                   warning("The method '", methodnames[i], "' was not fitted.")
                   next
                 }
-                if (!is.null(x@phi.centers)){
-                  x.radial <- cbind(cos(x@phi.centers[iph]+phi.angles),
-                                    sin(x@phi.centers[iph]+phi.angles))
-                  if(!is.null(x@theta.centers))
-                    x.radial <- cbind(x.radial,
-                                      cos(x@theta.centers[ith] +
-                                          rep(theta.angles,
-                                              each= length(phi.angles))))
+                if (!is.null(phi.centers)) {
+                  x.radial <- cbind(cos(phi.centers[iph]+phi.angles),
+                                    sin(phi.centers[iph]+phi.angles))
+                  if (!is.null(phi.centers))
+                    x.radial <-
+                      cbind(x.radial,
+                            cos(rep(theta.angles, each = length(phi.angles))
+                                + theta.centers[ith]))
                   
                 } else x.radial <- matrix(1, nrow=1, ncol=1)
                 
                 x.time <- NULL
-                if(!is.null(x@T)) x.time <- x@T[iT]
+                if (!is.null(Time)) x.time <- Time[iT]
                 x.eval <- seq(from = max(dotsRFfit$xlim[1],1e-3),
                               to = dotsRFfit$xlim[2], len = 150) 
                 
@@ -528,18 +520,18 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
             
             
             if (has.sd && plot.sd) {
-              sdnot0 <-  x@sd[ ,iph, ith, iT] != 0
-              arrows(x@centers[sdnot0],
-                     x@emp.vario[sdnot0 ,iph, ith,iT] - x@sd[sdnot0,iph,ith,iT],
-                     x@centers[sdnot0],
-                     x@emp.vario[sdnot0 ,iph, ith,iT] + x@sd[sdnot0,iph,ith,iT],
+              sdnot0 <-  sd[ ,iph, ith, iT] != 0
+              arrows(centers[sdnot0],
+                     ev[sdnot0 ,iph, ith,iT] - sd[sdnot0,iph,ith,iT],
+                     centers[sdnot0],
+                     ev[sdnot0 ,iph, ith,iT] + sd[sdnot0,iph,ith,iT],
                      code=2, angle=90, length=0.05, col=col)
             }
             
           } # nphi
           
           
-          pifactor <- signif((x@phi.centers[1:n.phi]) / pi, 2)
+          pifactor <- signif((phi.centers[1:n.phi]) / pi, 2)
           
           len.mnames <- length(plotted.meth)
           string.emp <- "empirical"
@@ -582,6 +574,13 @@ plotRFempVariog <- function(x, model, nmax.phi, nmax.theta, nmax.T,
   if (!is.null(xlab))
     do.call(graphics::title, args=c(dots, xlab=xlab, outer=TRUE))
 
-  close.screen(all.screens=TRUE)
-  
+  if (graphics$close_screen) {
+    close.screen(all.scr)
+    all.scr <- NULL
+  }
+ 
+  return(invisible(all.scr))
 }
+
+setMethod(f="plot", signature(x="RFempVariog", y="missing"),
+          function(x, y, ...) RFplotEmpVariogram(x, ...))
